Writing a changelog entry
-------------------------

Please put a new file in this directory named `xxxx.<type>.rst`, where

- `xxxx` is the pull request number associated with this entry
- `<type>` is one of:
  - feature
  - bugfix
  - doc
  - removal
  - misc

Inside the file, please write a short description of what you have changed, and how it impacts users of `zarr-python`.
